# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/aeiou/',
                'doc_host': 'https://drscotthawley.github.io',
                'git_url': 'https://github.com/drscotthawley/aeiou/',
                'lib_path': 'aeiou'},
  'syms': { 'aeiou.chunkadelic': { 'aeiou.chunkadelic.blow_chunks': ( 'https://drscotthawley.github.io/aeiou/chunkadelic.html#blow_chunks',
                                                                      'https://github.com/drscotthawley/aeiou//blob/main/aeiou/chunkadelic.py#L18'),
                                   'aeiou.chunkadelic.main': ( 'https://drscotthawley.github.io/aeiou/chunkadelic.html#main',
                                                               'https://github.com/drscotthawley/aeiou//blob/main/aeiou/chunkadelic.py#L77'),
                                   'aeiou.chunkadelic.process_one_file': ( 'https://drscotthawley.github.io/aeiou/chunkadelic.html#process_one_file',
                                                                           'https://github.com/drscotthawley/aeiou//blob/main/aeiou/chunkadelic.py#L46')},
            'aeiou.core': { 'aeiou.core.fast_scandir': ( 'https://drscotthawley.github.io/aeiou/core.html#fast_scandir',
                                                         'https://github.com/drscotthawley/aeiou//blob/main/aeiou/core.py#L47'),
                            'aeiou.core.get_audio_filenames': ( 'https://drscotthawley.github.io/aeiou/core.html#get_audio_filenames',
                                                                'https://github.com/drscotthawley/aeiou//blob/main/aeiou/core.py#L74'),
                            'aeiou.core.is_silence': ( 'https://drscotthawley.github.io/aeiou/core.html#is_silence',
                                                       'https://github.com/drscotthawley/aeiou//blob/main/aeiou/core.py#L26'),
                            'aeiou.core.load_audio': ( 'https://drscotthawley.github.io/aeiou/core.html#load_audio',
                                                       'https://github.com/drscotthawley/aeiou//blob/main/aeiou/core.py#L13'),
                            'aeiou.core.makedir': ( 'https://drscotthawley.github.io/aeiou/core.html#makedir',
                                                    'https://github.com/drscotthawley/aeiou//blob/main/aeiou/core.py#L35')},
            'aeiou.datasets': { 'aeiou.datasets.AudioDataset': ( 'https://drscotthawley.github.io/aeiou/datasets.html#audiodataset',
                                                                 'https://github.com/drscotthawley/aeiou//blob/main/aeiou/datasets.py#L131'),
                                'aeiou.datasets.AudioDataset.__getitem__': ( 'https://drscotthawley.github.io/aeiou/datasets.html#__getitem__',
                                                                             'https://github.com/drscotthawley/aeiou//blob/main/aeiou/datasets.py#L238'),
                                'aeiou.datasets.AudioDataset.__init__': ( 'https://drscotthawley.github.io/aeiou/datasets.html#__init__',
                                                                          'https://github.com/drscotthawley/aeiou//blob/main/aeiou/datasets.py#L137'),
                                'aeiou.datasets.AudioDataset.__len__': ( 'https://drscotthawley.github.io/aeiou/datasets.html#__len__',
                                                                         'https://github.com/drscotthawley/aeiou//blob/main/aeiou/datasets.py#L207'),
                                'aeiou.datasets.AudioDataset.get_data_range': ( 'https://drscotthawley.github.io/aeiou/datasets.html#get_data_range',
                                                                                'https://github.com/drscotthawley/aeiou//blob/main/aeiou/datasets.py#L188'),
                                'aeiou.datasets.AudioDataset.get_next_chunk': ( 'https://drscotthawley.github.io/aeiou/datasets.html#get_next_chunk',
                                                                                'https://github.com/drscotthawley/aeiou//blob/main/aeiou/datasets.py#L211'),
                                'aeiou.datasets.AudioDataset.load_file_ind': ( 'https://drscotthawley.github.io/aeiou/datasets.html#load_file_ind',
                                                                               'https://github.com/drscotthawley/aeiou//blob/main/aeiou/datasets.py#L185'),
                                'aeiou.datasets.AudioDataset.preload_files': ( 'https://drscotthawley.github.io/aeiou/datasets.html#preload_files',
                                                                               'https://github.com/drscotthawley/aeiou//blob/main/aeiou/datasets.py#L200'),
                                'aeiou.datasets.FillTheNoise': ( 'https://drscotthawley.github.io/aeiou/datasets.html#fillthenoise',
                                                                 'https://github.com/drscotthawley/aeiou//blob/main/aeiou/datasets.py#L62'),
                                'aeiou.datasets.FillTheNoise.__call__': ( 'https://drscotthawley.github.io/aeiou/datasets.html#__call__',
                                                                          'https://github.com/drscotthawley/aeiou//blob/main/aeiou/datasets.py#L69'),
                                'aeiou.datasets.FillTheNoise.__init__': ( 'https://drscotthawley.github.io/aeiou/datasets.html#__init__',
                                                                          'https://github.com/drscotthawley/aeiou//blob/main/aeiou/datasets.py#L64'),
                                'aeiou.datasets.Mono': ( 'https://drscotthawley.github.io/aeiou/datasets.html#mono',
                                                         'https://github.com/drscotthawley/aeiou//blob/main/aeiou/datasets.py#L97'),
                                'aeiou.datasets.Mono.__call__': ( 'https://drscotthawley.github.io/aeiou/datasets.html#__call__',
                                                                  'https://github.com/drscotthawley/aeiou//blob/main/aeiou/datasets.py#L99'),
                                'aeiou.datasets.NormInputs': ( 'https://drscotthawley.github.io/aeiou/datasets.html#norminputs',
                                                               'https://github.com/drscotthawley/aeiou//blob/main/aeiou/datasets.py#L85'),
                                'aeiou.datasets.NormInputs.__call__': ( 'https://drscotthawley.github.io/aeiou/datasets.html#__call__',
                                                                        'https://github.com/drscotthawley/aeiou//blob/main/aeiou/datasets.py#L93'),
                                'aeiou.datasets.NormInputs.__init__': ( 'https://drscotthawley.github.io/aeiou/datasets.html#__init__',
                                                                        'https://github.com/drscotthawley/aeiou//blob/main/aeiou/datasets.py#L87'),
                                'aeiou.datasets.PadCrop': ( 'https://drscotthawley.github.io/aeiou/datasets.html#padcrop',
                                                            'https://github.com/drscotthawley/aeiou//blob/main/aeiou/datasets.py#L21'),
                                'aeiou.datasets.PadCrop.__call__': ( 'https://drscotthawley.github.io/aeiou/datasets.html#__call__',
                                                                     'https://github.com/drscotthawley/aeiou//blob/main/aeiou/datasets.py#L41'),
                                'aeiou.datasets.PadCrop.__init__': ( 'https://drscotthawley.github.io/aeiou/datasets.html#__init__',
                                                                     'https://github.com/drscotthawley/aeiou//blob/main/aeiou/datasets.py#L22'),
                                'aeiou.datasets.PadCrop.draw_chunk': ( 'https://drscotthawley.github.io/aeiou/datasets.html#draw_chunk',
                                                                       'https://github.com/drscotthawley/aeiou//blob/main/aeiou/datasets.py#L32'),
                                'aeiou.datasets.PhaseFlipper': ( 'https://drscotthawley.github.io/aeiou/datasets.html#phaseflipper',
                                                                 'https://github.com/drscotthawley/aeiou//blob/main/aeiou/datasets.py#L51'),
                                'aeiou.datasets.PhaseFlipper.__call__': ( 'https://drscotthawley.github.io/aeiou/datasets.html#__call__',
                                                                          'https://github.com/drscotthawley/aeiou//blob/main/aeiou/datasets.py#L58'),
                                'aeiou.datasets.PhaseFlipper.__init__': ( 'https://drscotthawley.github.io/aeiou/datasets.html#__init__',
                                                                          'https://github.com/drscotthawley/aeiou//blob/main/aeiou/datasets.py#L53'),
                                'aeiou.datasets.RandPool': ( 'https://drscotthawley.github.io/aeiou/datasets.html#randpool',
                                                             'https://github.com/drscotthawley/aeiou//blob/main/aeiou/datasets.py#L73'),
                                'aeiou.datasets.RandPool.__call__': ( 'https://drscotthawley.github.io/aeiou/datasets.html#__call__',
                                                                      'https://github.com/drscotthawley/aeiou//blob/main/aeiou/datasets.py#L76'),
                                'aeiou.datasets.RandPool.__init__': ( 'https://drscotthawley.github.io/aeiou/datasets.html#__init__',
                                                                      'https://github.com/drscotthawley/aeiou//blob/main/aeiou/datasets.py#L74'),
                                'aeiou.datasets.RandomGain': ( 'https://drscotthawley.github.io/aeiou/datasets.html#randomgain',
                                                               'https://github.com/drscotthawley/aeiou//blob/main/aeiou/datasets.py#L118'),
                                'aeiou.datasets.RandomGain.__call__': ( 'https://drscotthawley.github.io/aeiou/datasets.html#__call__',
                                                                        'https://github.com/drscotthawley/aeiou//blob/main/aeiou/datasets.py#L125'),
                                'aeiou.datasets.RandomGain.__init__': ( 'https://drscotthawley.github.io/aeiou/datasets.html#__init__',
                                                                        'https://github.com/drscotthawley/aeiou//blob/main/aeiou/datasets.py#L120'),
                                'aeiou.datasets.Stereo': ( 'https://drscotthawley.github.io/aeiou/datasets.html#stereo',
                                                           'https://github.com/drscotthawley/aeiou//blob/main/aeiou/datasets.py#L103'),
                                'aeiou.datasets.Stereo.__call__': ( 'https://drscotthawley.github.io/aeiou/datasets.html#__call__',
                                                                    'https://github.com/drscotthawley/aeiou//blob/main/aeiou/datasets.py#L105')},
            'aeiou.hpc': { 'aeiou.hpc.HostPrinter': ( 'https://drscotthawley.github.io/aeiou/hpc.html#hostprinter',
                                                      'https://github.com/drscotthawley/aeiou//blob/main/aeiou/hpc.py#L35'),
                           'aeiou.hpc.HostPrinter.__call__': ( 'https://drscotthawley.github.io/aeiou/hpc.html#__call__',
                                                               'https://github.com/drscotthawley/aeiou//blob/main/aeiou/hpc.py#L44'),
                           'aeiou.hpc.HostPrinter.__init__': ( 'https://drscotthawley.github.io/aeiou/hpc.html#__init__',
                                                               'https://github.com/drscotthawley/aeiou//blob/main/aeiou/hpc.py#L37'),
                           'aeiou.hpc.freeze': ( 'https://drscotthawley.github.io/aeiou/hpc.html#freeze',
                                                 'https://github.com/drscotthawley/aeiou//blob/main/aeiou/hpc.py#L77'),
                           'aeiou.hpc.get_accel_config': ( 'https://drscotthawley.github.io/aeiou/hpc.html#get_accel_config',
                                                           'https://github.com/drscotthawley/aeiou//blob/main/aeiou/hpc.py#L17'),
                           'aeiou.hpc.n_params': ( 'https://drscotthawley.github.io/aeiou/hpc.html#n_params',
                                                   'https://github.com/drscotthawley/aeiou//blob/main/aeiou/hpc.py#L69'),
                           'aeiou.hpc.save': ( 'https://drscotthawley.github.io/aeiou/hpc.html#save',
                                               'https://github.com/drscotthawley/aeiou//blob/main/aeiou/hpc.py#L49')},
            'aeiou.spectrofu': { 'aeiou.spectrofu.main': ( 'https://drscotthawley.github.io/aeiou/spectrofu.html#main',
                                                           'https://github.com/drscotthawley/aeiou//blob/main/aeiou/spectrofu.py#L64'),
                                 'aeiou.spectrofu.process_one_file': ( 'https://drscotthawley.github.io/aeiou/spectrofu.html#process_one_file',
                                                                       'https://github.com/drscotthawley/aeiou//blob/main/aeiou/spectrofu.py#L32'),
                                 'aeiou.spectrofu.save_stft': ( 'https://drscotthawley.github.io/aeiou/spectrofu.html#save_stft',
                                                                'https://github.com/drscotthawley/aeiou//blob/main/aeiou/spectrofu.py#L21')},
            'aeiou.viz': { 'aeiou.viz.audio_spectrogram_image': ( 'https://drscotthawley.github.io/aeiou/viz.html#audio_spectrogram_image',
                                                                  'https://github.com/drscotthawley/aeiou//blob/main/aeiou/viz.py#L126'),
                           'aeiou.viz.embeddings_table': ( 'https://drscotthawley.github.io/aeiou/viz.html#embeddings_table',
                                                           'https://github.com/drscotthawley/aeiou//blob/main/aeiou/viz.py#L31'),
                           'aeiou.viz.pca_point_cloud': ( 'https://drscotthawley.github.io/aeiou/viz.html#pca_point_cloud',
                                                          'https://github.com/drscotthawley/aeiou//blob/main/aeiou/viz.py#L60'),
                           'aeiou.viz.plot_jukebox_embeddings': ( 'https://drscotthawley.github.io/aeiou/viz.html#plot_jukebox_embeddings',
                                                                  'https://github.com/drscotthawley/aeiou//blob/main/aeiou/viz.py#L163'),
                           'aeiou.viz.print_stats': ( 'https://drscotthawley.github.io/aeiou/viz.html#print_stats',
                                                      'https://github.com/drscotthawley/aeiou//blob/main/aeiou/viz.py#L81'),
                           'aeiou.viz.proj_pca': ( 'https://drscotthawley.github.io/aeiou/viz.html#proj_pca',
                                                   'https://github.com/drscotthawley/aeiou//blob/main/aeiou/viz.py#L48'),
                           'aeiou.viz.spectrogram_image': ( 'https://drscotthawley.github.io/aeiou/viz.html#spectrogram_image',
                                                            'https://github.com/drscotthawley/aeiou//blob/main/aeiou/viz.py#L100'),
                           'aeiou.viz.tokens_spectrogram_image': ( 'https://drscotthawley.github.io/aeiou/viz.html#tokens_spectrogram_image',
                                                                   'https://github.com/drscotthawley/aeiou//blob/main/aeiou/viz.py#L147')}}}